@@ -4,6 +4,7 @@ use std::time::Duration;
 
 use prost_types::Any;
 use serde::{Deserialize, Serialize};
+use tendermint::trust_threshold::TrustThresholdFraction;
 use tendermint_proto::Protobuf;
 
 use ibc_proto::ibc::core::client::v1::IdentifiedClientState;
@@ -58,6 +59,15 @@ impl AnyClientState {
         }
     }
 
+    pub fn trust_threshold(&self) -> Option<TrustThresholdFraction> {
+        match self {
+            AnyClientState::Tendermint(state) => Some(state.trust_level),
+
+            #[cfg(any(test, feature = "mocks"))]
+            AnyClientState::Mock(_) => None,
+        }
+    }
+
     pub fn client_type(&self) -> ClientType {
         match self {
             Self::Tendermint(state) => state.client_type(),
