@@ -197,23 +197,23 @@ mod tests {
             // Additionally check the events and the output objects in the result.
             match res {
                 Ok(proto_output) => {
-                    assert_eq!(
+                    assert!(
                         test.want_pass,
-                        true,
                         "write_ack: test passed but was supposed to fail for test: {}, \nparams {:?} {:?}",
                         test.name,
                         test.packet.clone(),
                         test.ctx.clone()
                     );
-                    assert_ne!(proto_output.events.is_empty(), true); // Some events must exist.
+
+                    assert!(!proto_output.events.is_empty()); // Some events must exist.
+
                     for e in proto_output.events.iter() {
                         assert!(matches!(e, &IbcEvent::WriteAcknowledgement(_)));
                     }
                 }
                 Err(e) => {
-                    assert_eq!(
-                        test.want_pass,
-                        false,
+                    assert!(
+                        !test.want_pass,
                         "write_ack: did not pass test: {}, \nparams {:?} {:?} error: {:?}",
                         test.name,
                         test.packet.clone(),
